import os
import os.path
import shutil
import string
import logging
import kraken.tools.Utils as Utils
import kraken.Constants
from kraken.entrytypes.Entry import Entry, loadKraEntry, getEntryRdfFile
from kraken.entrytypes.MetaData import MetaData, loadMetaData, generateCache, updateCache
from kraken.tools.Utils import cleanExit
import kraken.tools.TextUi as TextUi

def description(system, runtime):
    return """
    "Creates a new entry either from a local file or or a webpage.
    In the future, creation from scratch and hollow entries will also be supported\n"
    """
#
#  Creates an entry
# 
def execute(system, runtime):    
    if runtime.arguments == []:
        interactiveCreate(system, runtime)
    if runtime.arguments == []:
        logging.critical("I know, you want a note, but this is not supported yet.")
        return
    if len(runtime.arguments) > 1:
        logging.warning("Multiple file models are not yet supported in this kraken version. Using only the first one") 
    # FIXME: this is the very old processing methodology from the kraken file. TO CHANGE.    
    temp = runtime.arguments[0]
    if (temp[0:7] == "http://"):
        if TextUi.confirm("This is a webpage. Create only a link?"):
            entry = createWebpageLink(system, runtime)
        else:    
            if not runtime.recursive:
               entry = createEntryForSingleWebpage(system, runtime)
            else:
               entry = createEntryForFullWebpage(system, runtime)
    else: # Local files 
        entry = createEntryForSingleFile(system, runtime)
    # FIXME: replace this with the entry.edit()
    #runtime.interactiveRead(system)
    entry.fillinEntryFromRuntime(runtime, system)
    entry.edit(isAnnotation = 0)
    entry.writeRDF(os.path.join(system.getProperty("tempDir"), runtime.entryDir))
    # print entry
    print "Kraken entry " + runtime.entryDir + " successfully created. Use this name for annotation"
    Utils.moveEntryToDestinationDir(system, runtime)
    # FIXME: the cache can be updated without regenerating
    metadata = loadMetaData(system, runtime)
    metadata.addEntry(entry)
    updateCache(system, runtime, metadata)

    
'''
   Interactive create
'''    
def interactiveCreate(system, runtime):
    print """
   Creating a new entry interactively. Enter a local file, a webpage 
 or a comma separated list of them.
   Press Enter to create an empty note.
    """
    temp = TextUi.inputString("Source")
    if temp != "":       
       runtime.arguments = string.split(temp,",")
    else:
       runtime.arguments = []
    
    
# ***************************************************************
#  Create the entry for a single file from the local filesystem
# ***************************************************************
def createEntryForSingleFile(system, runtime):
    print "Creating an entry based on local files"
    print "Checking if the files exist..."
    localfiles = []
    for filename in runtime.arguments:
       filename = os.path.expanduser(filename)
       filename = os.path.abspath(filename)
       if not os.path.exists(filename):
           logging.critical(filename + " does not exist")
           cleanExit(1)
       localfiles.append(filename)    
    Utils.createEntry(system, runtime)
    print "Copying the files..."
    for filename in localfiles:    
       shutil.copy2(filename, os.path.join(system.getProperty("tempDir"), runtime.entryDir))
    entry = Entry()
    entry.originalURIs = localfiles
    entry.localFileNames = []
    for filename in localfiles:
       entry.localFileNames.append(os.path.split(filename)[1])
    print "Kraken entry " + runtime.entryDir + " successfully created"
    return entry


def createWebpageLink(system, runtime):
    Utils.createEntry(system, runtime)
    targetdir = os.path.join(system.getProperty("tempDir"), runtime.entryDir)
    # now, create the kraken file
    entry = Entry()
    entry.originalURIs = runtime.arguments
    return entry;
    
  
# ***********************************************************
#  Create a kraken entry for a single webpage
# ***********************************************************
def createEntryForSingleWebpage(system, runtime):
    Utils.createEntry(system, runtime)
    targetdir = os.path.join(system.getProperty("tempDir"), runtime.entryDir)
    # FIXME: this is not necessary, probably if I use join
    #if os.name == "nt":
    #   targetdir = "\"" + string.replace(targetdir,"/","\\\\") + "\""
    if len(runtime.arguments) > 1:
        logging.critical("You should enter a single web address!")
        return
    command = (kraken.Constants.COMMAND_DOWNLOAD_SINGLE_FILE + '"' + 
           runtime.arguments[0] + '"' +
          ' --directory-prefix="' + targetdir + '"')
    logging.info("Executing: " + command)
    os.system(command)
    # now, create the kraken file
    entry = Entry()
    entry.originalURIs = runtime.arguments
    # get the http filename, simply picking the first file in the directory    
    for x in os.listdir(targetdir):
       if not os.path.isdir(x):
           entry.localFileNames = [x]
           #print entry.localFileNames
    return entry;

# **********************************************************
#  Create the kraken entry for a full webpage
# ***********************************************************
def createEntryForFullWebpage(system, runtime):
    if os.name == "nt":
        # targetdir = "\"" + string.replace(targetdir,"/","\\\\") + "\""
        print "This command does not work correctly in Windows, because of some file"
        print "name mapping issues. It is a wget problem, but until I find a solution"
        print "I have disabled it"
        os._exit(0)       
    Utils.createEntry(system, runtime)
    targetdir = os.path.join(system.getProperty("tempDir"), runtime.entryDir)
    print targetdir      
    command = (kraken.Constants.COMMAND_DOWNLOAD_FULLPAGE + runtime.inputHttp +
      " --directory-prefix="+targetdir)
    print command
    os.system(command)
    # now, create the cocoon file
    entry = Entry()
    entry.originalURIs = [runtime.inputHttp]
    temp = runtime.inputHttp[7:] # got rid of http://
    #if temp[-1] != "/": temp += "/"
    # get the http filename, simply picking the first file in the directory
    resultFile = os.path.join(system.getProperty("tempDir"), runtime.entryDir, temp)
    log("Resultfile: " + resultFile)
    if os.path.isdir(resultFile):    
       listdir = os.listdir(resultFile)
       for priv in ("index.html", "index.htm", os.path.split(runtime.inputFile)[1]):
          if priv in listdir:
             entry.localFileNames = [temp + priv] 
             logging.info("Filename is:" + entry.localFileNames[0])
          else:
             logging.warning("Could not determine the local file name")
    elif os.path.exists(resultFile):
        entry.localFileNames = [temp]
    else:
        logging.warning("Can not identify the main file"+temp)
    return entry

