import sys
import shutil
import os.path
import logging
import kraken.tools.Utils as Utils
from kraken.entrytypes.MetaData import loadMetaData
from kraken.presentation.Query import Query
import kraken.Constants
from kraken.presentation.Presentation import generateHtml
from kraken.presentation.FilterEditor import createFilterWithVerify, createRankerWithVerify
from kraken.presentation.Rankers import rankMetaData

def description(system, runtime):
    t  = "Generates a HTML file from the content of the kraken. The default\n"
    t += "location of this file is " + os.path.join(system.getProperty("destinationDir"), kraken.Constants.DEFAULT_HTML_FILE) + "\n" 
    t += "but it can be changed using the --outputfile option. \n\n"
    t += "It is usually used together with a query.\n"
    return t

#
#  Writes out a list of the cocoon in the html format.
#
def execute(system, runtime):
    logging.info("Generating html...")
    if runtime.outputFile == "":
       runtime.outputFile = os.path.join(system.getProperty("destinationDir"), kraken.Constants.DEFAULT_HTML_FILE)
    metadata = loadMetaData(system, runtime)
    
    #query = Query()
    #query.fillFromRuntime(runtime)
    #query.edit()        
    #metadata = query.filterMetaData(metadata)
    
    flt = createFilterWithVerify(metadata)    
    metadata = flt.filterMetaData(metadata)
    ranker = createRankerWithVerify(metadata)
    metadata = rankMetaData(metadata, ranker)
    
    temp = generateHtml(system, runtime, metadata)
    Utils.writeOutput(system, runtime, temp)
    # and now copy the *.css
    scriptpath = os.path.split(sys.argv[0])[0]
    if scriptpath == "":
         cssfile = kraken.Constants.DEFAULT_CSS_FILE
    else:
         cssfile = os.path.join(scriptpath, kraken.Constants.DEFAULT_CSS_FILE)
    if not os.path.isfile(cssfile):
        logging.warning("Could not found the css file: " + cssfile)
        return
    shutil.copy(cssfile, system.getProperty("destinationDir"))
