from rdflib.URIRef import URIRef
from rdflib.Literal import Literal
from rdflib.BNode import BNode
from rdflib.Namespace import Namespace
from rdflib.constants import TYPE
from rdflib.TripleStore import TripleStore
from kraken.entrytypes.EntryBase import EntryBase
import bib2RDF
from kraken.tools.UniqueIdGenerator import getUniqueId

class BibTeXEntry(EntryBase):

  # the self description of the class
  namespaces = {}
  # the namespaces  
  namespaces["bibtex-rdf"] = "http://www.cs.ucf.edu/~lboloni/Programming/KrakenWeb/"
  BIBTEX = Namespace(namespaces["bibtex-rdf"]);

  #
  #   -----------  publication types
  #
  article = 'article'
  techreport = 'techreport'
  inproceedings = 'inproceedings'
  misc = 'misc'
  inbook = 'inbook'
  phdthesis = 'phdthesis'

  #
  #   -----------  properties
  #
  allowed_properties = [
    "id",
    'author',
    'title',
    'booktitle',
    'chapter',
    'month',
    'year',
    'pages',
    'number',
    'journal',
    'volume',
    'publisher',
    'howpublished',
    'institution',
    'school',
    'note' ]
  
  def __init__(self):
      EntryBase.__init__(self)
      self.filecontents_source = ""
      self.resourceURI = URIRef("bibtex://" + getUniqueId())    
      
  def loadBibTeXFile(self, filepath):
    try:
        fd = open(filepath, 'r')
        self.filecontents_source = fd.readlines()
        fd.close()
    except:
        print 'Could not open file:', filepath
    washeddata = bib2RDF.bibtexwasher(self.filecontents_source)
    bib2RDF.bibtexdecoder(washeddata, self)
      
  def getMapping(self, field):
      return self.BIBTEX[field]
      
  def getResourceURI(self):
      return self.resourceURI
#
#   -----------      properties accessors
#
  def getType(self):
      return self.fields["type"]

  def __str__(self):
      t = "BIBTEX entry : " + self.fields["id"] + "\n"
      for property_name in self.fields.keys():
        t += "\t" + property_name + "\t = " + self.fields[property_name] + "\n"
      return t


