import os.path
import kraken.Constants
import time

class TableFormat:

    def __init__(self):
        self.classTable = "maintable"
        self.classTdOdd = "tablecell-odd"
        self.classTdEven = "tablecell-even"
        self.classPdescription = "description"
        self.classPkeywords = "keywords"
        self.classPkrakenpos = "kraken-pos"

    '''
       Generates a table of lists based on the metadata information
    '''        
    def generateEntryTable(self, metadata):
       temp = ""
       temp +='<table class=' + self.classTable + ' cols=2 width="100%">\n'
       odd = 1
              
       for a in metadata.entries:
          if a.title == "": 
              a.title = "Unknown title"
          if a.description == "": 
              a.description = "No description"
          # handling the different color of odd and even rows
          if odd:
              csscell = self.classTdOdd
              odd = 0
          else:
              csscell = self.classTdEven
              odd = 1
          # create the row
          temp += "<tr>\n"
          # first cell: title, description
          temp += '<td class=' + csscell + ' width="70%">'
          for x in a.localFileNames:
             temp += '<a href="file:///' + a.krakenDirName + "/" + a.directoryName + "/" + x + '">' +  a.title + "</a><br/>\n"
          if len(a.localFileNames) == 0:
              if len(a.originalURIs) != 0:
                 for x in a.originalURIs:
                   temp += '<a href="' + x + '">' +  a.title + "</a><br/>\n"
              else:      
                 temp += '<a href="file:///' + a.krakenDirName + "/" + a.directoryName + "/" + '">' + a.title  + "</a>\n"              
          temp += "<p class=" + self.classPdescription + ">" + a.description + "</p>\n"
          temp += self.__generateMetaData(a, metadata)
          temp += "</td>\n"
          # second cell: original URL, date
          temp += '<td class=' + csscell + '>\n'
          for x in a.originalURIs:
             temp += "<p class=originalUrl>"+ x + "</p>\n"
          temp += "<p class=date>"+ "Date:" + time.strftime(kraken.Constants.HTML_DATE_FORMAT, a.date) + "</p>\n"
          temp += "<p class=" + self.classPkeywords+">"+ "Keywords: "          
          for cats in a.keywords:
              temp += cats + ", "
          temp = temp[:-2]    
          temp += "</p>\n"          
          temp += "<p class=" + self.classPkrakenpos + ">" + "Entry: " + a.directoryName + "</p>\n"          
          temp += "</td>\n"
          # end of row
          temp += "</tr>\n"
       temp += "</table>\n"
       return temp
        
        
        
    def __generateMetaData(self, entry, metadata):
      temp = ""
      metadataDir = (entry.krakenDirName + "/" + entry.directoryName + "/" + 
          kraken.Constants.DIRNAME_METADATA + "/")
      #temp += self.__addMetaDataLink(metadataDir, kraken.Constants.ENTRY_TYPE_FILE_BIBTEX, "[BibTeX]")
      #temp += self.__addMetaDataLink(metadataDir, "summary.txt", "[Summary]")
      #temp += self.__addMetaDataLink(metadataDir, "quotes.txt", "[Quotes]")
      for a in metadata.descriptors.values():
          if a.nativeFileName != None:
             temp += self.__addMetaDataLink(metadataDir, a.nativeFileName, "[" + a.name + "]")
      return temp
    
    def __addMetaDataLink(self, metadataDir, mdFile, mdLabel):
       # FIXME: this is for Windows       
       if os.path.exists(metadataDir + mdFile):
           return '<a href="file:///' + metadataDir + "/" + mdFile + '">' +  mdLabel + "</a>\n"
       else:
           return ""
        
